dnl @synopsis AX_SOCI
dnl 
dnl This macro tries to find Soci C API header and library locations.
dnl
dnl We define the following configure script flags:
dnl
dnl	--with-soci: Give prefix for both library and headers, and try
dnl		     to guess subdirectory names for each.  (e.g. add /lib and
dnl		     /include onto given dir names, and other common schemes.)
dnl
dnl @version 1.3, 2009/05/02
dnl @author Denis Arnaud <denis_arnaud@users.sourceforge.net>
dnl
dnl @version 1.2, 2007/02/20
dnl @author Warren Young <socipp@etr-usa.com>

AC_DEFUN([AX_SOCI],
[
#
# Set up configure script macros
#
AC_ARG_WITH(soci,
	[--with-soci=<path>     root directory path of Soci installation],
	[SOCI_lib_check="$with_soci/lib64/soci $with_soci/lib/soci $with_soci/lib64 $with_soci/lib"
	SOCI_inc_check="$with_soci/include $with_soci/include/soci"],
	[SOCI_lib_check="/usr/lib64 /usr/lib /usr/lib64/soci /usr/lib/soci /usr/local/lib64 /usr/local/lib /opt/soci/lib64 /opt/soci/lib /usr/local/lib64/soci /usr/local/lib/soci /usr/local/soci/lib64 /usr/local/soci/lib /opt/soci/lib64/soci /opt/soci/lib/soci"
	SOCI_inc_check="/usr/include /usr/include/soci /usr/local/include /opt/soci/include /usr/local/include/soci /usr/local/soci/include /usr/local/soci/include/soci /opt/soci/include/soci"])

# SOCI library
SOCI_CORE_LIB=soci_core
SOCI_MYSQL_LIB=soci_mysql

#
# Look for Soci Core API library
#
AC_MSG_CHECKING([for Soci library directory])
SOCI_libdir=
for m in $SOCI_lib_check
do
	if test -d "$m" && \
		(test -f "$m/lib$SOCI_CORE_LIB.so" || test -f "$m/lib$SOCI_CORE_LIB.a")
	then
		SOCI_libdir=$m
		break
	fi
done

if test -z "$SOCI_libdir"
then
	AC_MSG_ERROR([Didn't find $SOCI_CORE_LIB library in '$SOCI_lib_check'])
fi

case "$SOCI_libdir" in
	/* ) ;;
	* )  AC_MSG_ERROR([The Soci library directory ($SOCI_libdir) must be an absolute path.]) ;;
esac

AC_MSG_RESULT([$SOCI_libdir])

case "$SOCI_libdir" in
  /usr/lib64) ;;
  /usr/lib) ;;
  *) SOCI_LIBS="-L${SOCI_libdir}" ;;
esac
LDFLAGS="$LDFLAGS ${SOCI_LIBS}"


#
# Look for Soci Core API headers
#
AC_MSG_CHECKING([for Soci include directory])
SOCI_incdir=
for m in $SOCI_inc_check
do
	if test -d "$m" && test -f "$m/soci/core/soci.h"
	then
		SOCI_incdir=$m
		break
	fi
done

if test -z "$SOCI_incdir"
then
	AC_MSG_ERROR([Didn't find the Soci include dir in '$SOCI_inc_check'])
fi

case "$SOCI_incdir" in
	/* ) ;;
	* )  AC_MSG_ERROR([The Soci include directory ($SOCI_incdir) must be an absolute path.]) ;;
esac

AC_MSG_RESULT([$SOCI_incdir])

case "$SOCI_incdir" in
  /usr/include) ;;
  *) SOCI_CFLAGS="-I${SOCI_incdir}" ;;
esac

SOCI_LIBS="${SOCI_LIBS} -l${SOCI_CORE_LIB} -l${SOCI_MYSQL_LIB} -ldl"

AC_SUBST(SOCI_CFLAGS)
AC_SUBST(SOCI_LIBS)

# Test linking with soci (note that it needs MySQL client to have been defined
# before)
save_LIBS="$LIBS"
if test -z "$MYSQL_LIBS"
then
	MYSQL_LIBS="-L/usr/lib64/mysql -L/usr/lib/mysql -lmysqlclient"
fi
LIBS="$LIBS $MYSQL_LIBS $SOCI_LIBS"
AC_CHECK_LIB($SOCI_CORE_LIB, soci_begin,
	     [], 
             [AC_MSG_ERROR([Could not find working Soci client library!])]
	     )
LIBS="$save_LIBS"
AC_SUBST(SOCI_CORE_LIB)
]) dnl AX_SOCI
